﻿using CE_MVVM_Toolkit.Interfaces;
using CommunityToolkit.Mvvm.ComponentModel;
using CommunityToolkit.Mvvm.Messaging;


namespace CE_MVVM_Toolkit.Models
{
    /// <summary>
    ///     This is the base class for all model objects. If this class is provided with an
    ///     <see cref="IMessenger" /> instance it will automatically register this class for receiving messages and provides a
    ///     property for the inherited classes to use the <see cref="IMessenger" />.
    /// </summary>
    public abstract class BaseModel : ObservableObject, IModel
    {
        /// <summary>
        ///     Creates the base model and registers to receive messages.
        /// </summary>
        /// <param name="messenger">The messenger to use for sending and receiving messages.</param>
        protected BaseModel(IMessenger messenger)
        {
            Messenger = messenger;
            Messenger?.RegisterAll(this);
        }

        /// <summary>
        ///     Creates the base model.
        /// </summary>
        protected BaseModel()
        {
        }

        /// <summary>
        ///     The <see cref="IMessenger" /> that is used for receiving and sending messages.
        /// </summary>
        protected IMessenger Messenger { get; }
    }
}