﻿using Carmenta.Engine;
using CE_MVVM_Toolkit.Interfaces.Map;

namespace CE_MVVM_Toolkit.Models.Map
{
    internal class EffectsModel : BaseModel, IEffectsModel
    {
        /// <summary>
        /// The MapModel
        /// </summary>
        private readonly IMapModel _mapModel;

        /// <summary>
        /// The brightnes contrast effects object 
        ///  </summary>
        private readonly BrightnessContrastEffect _brightnessContrastEffect;

        /// <summary>
        /// Constructor
        /// </summary>
        /// <param name="mapModel">Dependency injected MapModel</param>
        public EffectsModel(IMapModel mapModel)
        {
            _mapModel = mapModel;

            _brightnessContrastEffect = new BrightnessContrastEffect();
            using (new Guard())
            {
                _mapModel.View.Effects.Add(_brightnessContrastEffect);
            }
        }

        /// <summary>
        /// Brightness property
        /// </summary>
        public double Brightness
        {
            get => _brightnessContrastEffect.Brightness;
            set
            {
                _brightnessContrastEffect.Brightness = value;
                _mapModel.View.Update();
                OnPropertyChanged();
            }
        }

        /// <summary>
        /// Contrast property
        /// </summary>
        public double Contrast
        {
            get => _brightnessContrastEffect.Contrast;
            set
            {
                _brightnessContrastEffect.Contrast = value;
                _mapModel.View.Update();
                OnPropertyChanged();
            }
        }
    }
}
