﻿using Carmenta.Engine;
using CE_MVVM_Toolkit.Interfaces.Map;

namespace CE_MVVM_Toolkit.Models.Map
{
    internal class MapModel : BaseModel, IMapModel
    {
        /// <summary>
        /// Carmenta Engine View property
        /// </summary>
        public View View { get; }

        public MapModel()
        {
            View view = LoadConfiguration("world_map.px");
            if (view != null)
            {
                // Store the view
                View = view;

                // Area Changed event
                View.AreaChanged += View_AreaChanged;
            }
        }

        public double NominalScale
        {
            get => View.NominalScale;
            set
            {
                if (View.NominalScale != value)
                {
                    View.NominalScale = value;
                    OnPropertyChanged();
                }
            }
        }


        private void View_AreaChanged(object sender, System.EventArgs e)
        {
            OnPropertyChanged(nameof(NominalScale));
        }

        /// <summary>
        /// Loads the map configuration
        /// </summary>
        /// <param name="fileName">The map configuration file name</param>
        /// <returns>The first public view found in the map configuration</returns>
        private static View LoadConfiguration(string fileName)
        {
            // Load configuration file.
            Configuration configuration = new Configuration(fileName);

            // Get view from configuration.
            View view = null;
            foreach (string key in configuration.PublicNames)
            {
                view = configuration.GetPublicObject(key) as View;
                if (view != null)
                {
                    break;
                }
            }
            return view;
        }
    }
}
