﻿using Carmenta.Engine;
using CE_MVVM_Toolkit.Interfaces.Map;
using CE_MVVM_Toolkit.Models.Map;
using CE_MVVM_Toolkit.Requests;
using CommunityToolkit.Mvvm.Input;
using CommunityToolkit.Mvvm.Messaging;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Input;

namespace CE_MVVM_Toolkit.ViewModels.Map
{
    public class AddAppDataViewModel : BaseViewModel
    {
        private IMapModel _mapModel;
        private MemoryDataSet _appDataSet;
        private CreateTool _createTool;
        public AddAppDataViewModel(IMapModel mapModel) {
            _mapModel= mapModel;
            RandomFeatureClickEvent = new RelayCommand(RandomFeatureClickEventHandler);
            ActivateInsertToolEvent = new RelayCommand(ActiveInsertToolEventHandler);
            _appDataSet = _mapModel.View.FindChildObject("ApplicationDataSet") as MemoryDataSet;

            _createTool = new CreateTool(_appDataSet);
            _createTool.CreateMode = ToolCreateMode.Point;
            _createTool.FeatureCreated += FeaturedCreatedEventHandler;

        }

        private void FeaturedCreatedEventHandler(object sender, FeatureCreatedEventArgs args)
        {
            //Reset to the Standard Tool after you have created line feature.
            WeakReferenceMessenger.Default.Send(new ChangeToolRequest(new StandardTool()));
        }

        private void ActiveInsertToolEventHandler()
        {
            //Change Tool
            WeakReferenceMessenger.Default.Send(new ChangeToolRequest(_createTool));

        }
        

        /// <summary>
        /// We insert a random feature within 0 20 longitude 0 50 latitude
        /// </summary>
        private void RandomFeatureClickEventHandler()
        {
            //randomize geolocation
            var rnd = new Random();
            var x = rnd.NextDouble() * 20.0;
            var y = rnd.NextDouble() * 50.0;

            var feature = new Feature(new PointGeometry(x, y), Crs.Wgs84LongLat);

            //insert feature into data set using a guard for thread saftey
            using (new Guard(_appDataSet))
            {
                _appDataSet.Insert(feature);
                _appDataSet.RefreshAllFeaturePresentation(true);
                _mapModel.View.Update();
            }
        }

        public ICommand RandomFeatureClickEvent { get; }

        public ICommand ActivateInsertToolEvent { get; }
    }
}
