﻿using CE_MVVM_Toolkit.Interfaces.Map;
using CommunityToolkit.Mvvm.Input;
using System;
using System.Windows.Input;

namespace CE_MVVM_Toolkit.ViewModels.Map
{
    public class EffectsViewModel : BaseViewModel
    {
        /// <summary>
        /// The effects model
        /// </summary>
        private readonly IEffectsModel _effectsModel;

        /// <summary>
        /// Constructor
        /// </summary>
        /// <param name="effectsModel">Dependency injected effects model</param>
        public EffectsViewModel(IEffectsModel effectsModel)
        {
            _effectsModel = effectsModel;
            RandomValueClickEvent = new RelayCommand(RandomValueClickEventHandler);
        }

        /// <summary>
        /// Brightness property
        /// </summary>
        public double Brightness
        {
            get => _effectsModel.Brightness;
            set
            {
                _effectsModel.Brightness = value;
                OnPropertyChanged();
            }
        }

        /// <summary>
        /// Contrast property
        /// </summary>
        public double Contrast
        {
            get => _effectsModel.Contrast;
            set
            {
                _effectsModel.Contrast = value;
                OnPropertyChanged();
            }
        }

        public ICommand RandomValueClickEvent { get; }

        private void RandomValueClickEventHandler()
        {
            Random rn = new Random();
            Brightness = rn.NextDouble()*2;
            Contrast = rn.NextDouble()*2;
        }
    }
}
