﻿using Carmenta.Engine;
using CE_MVVM_Toolkit.Interfaces.Map;
using CE_MVVM_Toolkit.Requests;
using CommunityToolkit.Mvvm.Messaging;

namespace CE_MVVM_Toolkit.ViewModels.Map
{
    public class MapViewModel : BaseViewModel, IRecipient<ChangeToolRequest>
    {
        private readonly IMapModel _mapModel;
        private ITool _tool;

        public MapViewModel(IMapModel mapModel)
        {
            _mapModel = mapModel;
            _mapModel.PropertyChanged += MapModel_PropertyChanged;

            Tool = new StandardTool();

            WeakReferenceMessenger.Default.Register<ChangeToolRequest>(this);
        }

        public View View => _mapModel.View;

        /// <summary>
        ///     The tool currently attached to the map.
        /// </summary>
        public ITool Tool
        {
            get => _tool;
            set => SetProperty(ref _tool, value);
        }

        /// <summary>
        ///     Error handling for the map control.
        /// </summary>
        public void OnMapControlError(object sender, Carmenta.Engine.Controls.ErrorEventArgs e)
        {
            View.UpdateEnabled = false;
        }

        public string NominalScale
        {
            get => "1 : " + _mapModel.NominalScale.ToString("N0");
            set
            {
                if (NominalScale == value)
                {
                    return;
                }

                NominalScale = value;
                OnPropertyChanged();
            }
        }

        private void MapModel_PropertyChanged(object sender, System.ComponentModel.PropertyChangedEventArgs e)
        {
            switch (e.PropertyName)
            {
                case nameof(NominalScale):
                    OnPropertyChanged(nameof(NominalScale));
                    break;
            }
        }

        public void Receive(ChangeToolRequest message)
        {
            Tool = message.Tool;
        }
    }
}